Event

Enum Event 

pub enum Event<'a> {
Show 16 variants Shutdown, LogMessage { prefix: &'a str, level: &'a str, text: &'a str, log_level: LogLevel, }, GetPropertyReply { name: &'a str, result: PropertyData<'a>, reply_userdata: u64, }, SetPropertyReply(u64), CommandReply(u64), StartFile, EndFile(EndFileReason), FileLoaded, ClientMessage(Vec<&'a str>), VideoReconfig, AudioReconfig, Seek, PlaybackRestart, PropertyChange { name: &'a str, change: PropertyData<'a>, reply_userdata: u64, }, QueueOverflow, Deprecated(mpv_event),
}

Variants



Shutdown

Received when the player is shutting down



LogMessage

Has not been tested, received when explicitly asked to MPV

Fields

prefix: &'a str
level: &'a str
text: &'a str
log_level: LogLevel


GetPropertyReply

Received when using get_property_async

Fields

name: &'a str
result: PropertyData<'a>
reply_userdata: u64


SetPropertyReply(u64)

Received when using set_property_async



CommandReply(u64)

Received when using command_async



StartFile

Event received when a new file is playing



EndFile(EndFileReason)

Event received when the file being played currently has stopped, for an error or not



FileLoaded

Event received when a file has been loaded, but has not been started



ClientMessage(Vec<&'a str>)



VideoReconfig



AudioReconfig



Seek

The player changed current position



PlaybackRestart



PropertyChange

Received when used with observe_property

Fields

name: &'a str
change: PropertyData<'a>
reply_userdata: u64


QueueOverflow

Received when the Event Queue is full



Deprecated(mpv_event)

A deprecated event